Learn R Programming

reveneraR (version 1.0.1)

check_status: Check Request Status

Description

This function is called by other functions that submit a requests to Revenera API. It checks the status code returned and tells the user if there was an error code and exits the function.

Usage

check_status(request_obj)

Arguments

Value

If status code is not 200, returns a message to console with appropriate error message and stops execution.