Learn R Programming

reveneraR (version 1.0.1)

get_categories_and_events: Get All Categories and Events for a List of Product Ids

Description

Returns all of the unique categories and events (basic and advanced) for each product id.

Usage

get_categories_and_events(rev_product_ids)

Value

Data frame with categories, events and event type by product id.

Arguments

rev_product_ids

A vector of Revenera product id's for which you want active user data.

Details

It is not recommended that your username be stored directly in your code. There are various methods and packages available that are more secure; this package does not require you to use any one in particular.

Examples

Run this code
if (FALSE) {
rev_user <- "my_username"
rev_pwd <- "super_secret"
logout(rev_user, rev_pwd)
Sys.sleep(30)
revenera_auth(rev_user, rev_pwd)
product_ids_list <- c("123", "456", "789")
session_id <- revenera_auth(rev_user, rev_pwd)
category_event <- get_categories_and_events(
  product_ids_list
)
}

Run the code above in your browser using DataLab