Learn R Programming

reveneraR (version 1.0.1)

logout: Remove authorization cookies (logout).

Description

Use this to remove the current authorization before re-authorizing.

Usage

logout(rev_username, rev_password)

Value

Nothing (successful logout), or an error message.

Arguments

rev_username

Revenera username.

rev_password

Revenera password.

Details

It is not recommended that these values be stored directly in your code. There are various methods and packages available that are more secure; this package does not require you to use any one in particular.

Examples

Run this code
if (FALSE) {
rev_user <- "my_username"
rev_pwd <- "super_secret"
revenera_auth(rev_user, rev_pwd)
logout(rev_user, rev_pwd)
}

Run the code above in your browser using DataLab