Learn R Programming

reveneraR (version 1.0.1)

revenera_auth: Login and Obtain Revenera API Session Id

Description

An authorizaton cookie must first be established before querying for data. This is done using your Revenera username and password. If there is an active cookie this function will fail. You must `logout()` first then

Usage

revenera_auth(rev_username, rev_password)

Value

Cookie authorization (which you won't see), or an error message.

Arguments

rev_username

Revenera username.

rev_password

Revenera password.

Details

It is not recommended that these values be stored directly in your code. There are various methods and packages available that are more secure; this package does not require you to use any one in particular.

Examples

Run this code
if (FALSE) {
rev_user <- "my_username"
rev_pwd <- "super_secret"
logout(rev_user, rev_pwd)
Sys.sleep(30)
revenera_auth(rev_user, rev_pwd)
}

Run the code above in your browser using DataLab